pub struct ToastableDialog {
toast_overlay: TemplateChild<ToastOverlay>,
child_content: PhantomData<Option<Widget>>,
}Fields
toast_overlay: TemplateChild<ToastOverlay>child_content: PhantomData<Option<Widget>>The child widget containing the content of this dialog.
Implementations
Sourceimpl ToastableDialog
impl ToastableDialog
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl ToastableDialog
impl ToastableDialog
Sourcefn child_content(&self) -> Option<Widget>
fn child_content(&self) -> Option<Widget>
The child widget containing the content of this dialog.
Sourcefn set_child_content(&self, content: Option<&Widget>)
fn set_child_content(&self, content: Option<&Widget>)
Set the child widget containing the content of this dialog.